@@ -1,8 +1,10 @@
 import grpc
 from oauthlib import oauth2
+from requests import HTTPError
 from requests_oauthlib import OAuth2Session
 
 from pyzeebe.credentials.base_credentials import BaseCredentials
+from pyzeebe.exceptions import InvalidOAuthCredentials
 
 
 class OAuthCredentials(BaseCredentials):
@@ -19,15 +21,20 @@ class OAuthCredentials(BaseCredentials):
 
     @staticmethod
     def get_access_token(url: str, client_id: str, client_secret: str, audience: str) -> str:
-        client = oauth2.BackendApplicationClient(client_id)
-        client.prepare_request_body(include_client_id=True)
-        with OAuth2Session(client=client) as session:
-            return session.post(url,
-                                data={
-                                    "client_id": client_id,
-                                    "client_secret": client_secret,
-                                    "audience": audience
-                                }).json()["access_token"]
+        try:
+            client = oauth2.BackendApplicationClient(client_id)
+            client.prepare_request_body(include_client_id=True)
+            with OAuth2Session(client=client) as session:
+                response = session.post(url,
+                                        data={
+                                            "client_id": client_id,
+                                            "client_secret": client_secret,
+                                            "audience": audience
+                                        })
+                response.raise_for_status()
+                return response.json()["access_token"]
+        except HTTPError:
+            raise InvalidOAuthCredentials(url=url, client_id=client_id, audience=audience)
 
     def get_connection_uri(self) -> str:
         return None
